@@ -254,9 +254,19 @@ supported_recurrences = {
     'first-wednesday': MonthlyRecurrence(week=1, day='Wednesday'),
     'first-thursday': MonthlyRecurrence(week=1, day='Thursday'),
     'first-friday': MonthlyRecurrence(week=1, day='Friday'),
+    'second-monday': MonthlyRecurrence(week=2, day='Monday'),
+    'second-tuesday': MonthlyRecurrence(week=2, day='Tuesday'),
+    'second-wednesday': MonthlyRecurrence(week=2, day='Wednesday'),
+    'second-thursday': MonthlyRecurrence(week=2, day='Thursday'),
+    'second-friday': MonthlyRecurrence(week=2, day='Friday'),
     'third-monday': MonthlyRecurrence(week=3, day='Monday'),
     'third-tuesday': MonthlyRecurrence(week=3, day='Tuesday'),
     'third-wednesday': MonthlyRecurrence(week=3, day='Wednesday'),
     'third-thursday': MonthlyRecurrence(week=3, day='Thursday'),
     'third-friday': MonthlyRecurrence(week=3, day='Friday'),
+    'fourth-monday': MonthlyRecurrence(week=4, day='Monday'),
+    'fourth-tuesday': MonthlyRecurrence(week=4, day='Tuesday'),
+    'fourth-wednesday': MonthlyRecurrence(week=4, day='Wednesday'),
+    'fourth-thursday': MonthlyRecurrence(week=4, day='Thursday'),
+    'fourth-friday': MonthlyRecurrence(week=4, day='Friday'),
 }
